@@ -52,12 +52,21 @@ class S3Bucket(Bucket):
 
         return [S3Cubby(self, key.key) for key in keys]
 
+    def list_iter(self, prefix=None, max_keys=None, **kwargs):
+        if prefix is not None:
+            kwargs['Prefix'] = prefix
+        if max_keys is not None:
+            kwargs['MaxKeys'] = max_keys
+
+        for obj in self._bucket.objects.filter(**kwargs).page_size(100):
+            yield S3Cubby(self, obj.key)
+
     def __eq__(self, other):
         if not isinstance(other, S3Bucket):
             return False
-        
-        return (self.service == other.service 
-        and self.name == other.name 
+
+        return (self.service == other.service
+        and self.name == other.name
         and self.location == other.location)
 
     def copy_key(self, dst_key: str, src_key: str, src_bucket_name: str = None):
@@ -237,7 +246,7 @@ class S3Cubby(Cubby):
     def __eq__(self, other):
         if not isinstance(other, S3Cubby):
             return False
-        
+
         return self.bucket == other.bucket and self.key == other.key
 
     def copy_to_native_cubby(self, cubby=None):
